Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FileServerService ¶
type FileServerService struct {
// contains filtered or unexported fields
}
FileServerService is a service that serves files from the Content Addressable Storage (CAS) over HTTP. It also serves shell scripts generated from Command messages, and directories as Tarballs.
func NewFileServerService ¶
func NewFileServerService(blobAccess blobstore.BlobAccess, maximumMessageSizeBytes int) *FileServerService
NewFileServerService creates a new ServeFilesService with an authorizing CAS if ServeFilesCasConfiguration is configured.
func (FileServerService) HandleCommand ¶
func (s FileServerService) HandleCommand(w http.ResponseWriter, req *http.Request)
HandleCommand serves a Command message from the Content Addressable Storage (CAS) as a shell script over HTTP.
func (FileServerService) HandleDirectory ¶
func (s FileServerService) HandleDirectory(w http.ResponseWriter, req *http.Request)
HandleDirectory serves a directory as a tarball.
func (FileServerService) HandleFile ¶
func (s FileServerService) HandleFile(w http.ResponseWriter, req *http.Request)
HandleFile serves a file from the Content Addressable Storage (CAS) over HTTP.
Click to show internal directories.
Click to hide internal directories.